==> cordova-sqlite-react-1.0.0.tgz: package/SqliteStore/index.ts <==
import { SQLitePlugin } from './../@types/SQLitePlugin.d';
import { CreateTableType, openDbSqlite } from '@utils/SQLite';
// import { createAndWriteInTable } from './createAndWriteInTable';
import { generateSQLCreateTable, generateSQLInsertInto } from '../stringSQL';


export class SqliteStore {
  static dbName = (process.env.REACT_APP_SQLITE_DB_NAME as string)
  static tableName = {
    config: 'localStorage',
  }


  static openDbSqlite = (nameDbSqlite = SqliteStore.dbName) => {

    if(!window.db || (nameDbSqlite && !window.db.openDBs[nameDbSqlite]) ){//!Object.keys(window.db.openDBs).length 
   
      return window.db = window.sqlitePlugin.openDatabase({
        name: nameDbSqlite,
        location: 'default',
        androidDatabaseProvider: 'system'
      });
      
    }
    
    return window.db as SQLitePlugin;
  }

  // private static createAndWriteInTable = createAndWriteInTable //TODO: Подумать как организовать такой подход
  private static createAndWriteInTable:CreateTableType = (payload, tableName, isCreateDate) => new Promise<{status: boolean}>((resolve, reject) => {
    let db = SqliteStore.openDbSqlite();
  
    let { newSQLCreate } = generateSQLCreateTable(payload, tableName, isCreateDate)
    let { newSQLInsert, arrValuesPayload } = generateSQLInsertInto(payload, tableName);
    console.group('SqliteStore.openDbSqlite')
      console.log('newSQLCreate: ', newSQLCreate)
      console.log('newSQLInsert: ', newSQLInsert)
      console.log('arrValuesPayload: ', arrValuesPayload)
    console.groupEnd();

    db.transaction(
      (tx) => {
        tx.executeSql(`DROP TABLE IF EXISTS ${tableName}`);
        tx.executeSql(newSQLCreate);
        tx.executeSql(newSQLInsert, arrValuesPayload, () => resolve({status: true}));
      },
      (err) => { console.error(`>>> Ошибка в SqliteStore -> createTable <<<: ${err}`); reject(new Error('Не удалось создать и записать в таблицу'))  },
      () => { console.dir('Успешное создание таблицы');  }
    )
  
  })

  static checkTable = (nameTable: string) => { 
    return new Promise<{status: boolean}>((resolve, reject) => {

      let db = SqliteStore.openDbSqlite();
      db.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${nameTable}'`, [],
        (res) => {
          
          if(res.rows.item(0) && res.rows.item(0).name === nameTable){    
            resolve({ status: true })
            return;
          }
          resolve({ status: false });                                        
        },
        (err) => { console.log(`Ошибка транзакции в SqliteStore.checkTable: ${err.message}.`); reject('Ошибка проверки таблицы') },    
      ); 
    })
  }



  static setItem = (key:string, value: any) => {
    if(window.cordova){
      return new Promise( (resolve, reject) => {
      
        let db = SqliteStore.openDbSqlite();
       //не проверяю таблицу в отдельной транзакции
        db.transaction(
          async (tx) => {
            try {
          
              let { status } =  await SqliteStore.checkTable(SqliteStore.tableName.config);

              if(status){
                tx.executeSql(`SELECT * FROM ${SqliteStore.tableName.config} WHERE key='${key}'`, [], 
                //Если есть данные и они не совпадают то обновим, если нет их совсем - добавим
                  (tx, res) => {
                    if(!res.rows.item(0)){

                      tx.executeSql(`INSERT INTO ${SqliteStore.tableName.config}(key, value, type) VALUES (?,?,?)`, 
                        [
                          key,
                          ((typeof value === 'object') || (typeof value === 'boolean')) ? JSON.stringify(value) : value,
                          typeof value
                        ],
                        () => {resolve({status: true, msg: 'Успешно положили данные в sqlite LocalStorage'})}
                      );

                    }else if(res.rows.item(0).value !== value){
                      console.dir('Обновляем данные SqliteStore');
                      tx.executeSql(`UPDATE ${SqliteStore.tableName.config} SET value = ?, type = ? WHERE key='${key}'`,
                        [
                          (typeof value === 'object' || typeof value === 'boolean') ? JSON.stringify(value) : value,
                          typeof value
                        ],
                        (tx, res) => { resolve({status: true, id: res.insertId})}
                      );

                    }else{

                      resolve({status: true, msg: 'Данные не обновил т.к. значение тоже'});

                    }
                  } 
                )
              }else{
                console.dir(`Попали в транзакцию создания таблицы ${SqliteStore.tableName.config}`);
                let payload = { key, value, type: typeof value };
                console.log('payload DarkMode для SqliteStore.createAndWriteInTable', payload);
                let dataStatus:object = await SqliteStore.createAndWriteInTable(payload, SqliteStore.tableName.config);
                console.log('dataStatus в SqliteStore.setItem', dataStatus);
                resolve(dataStatus)
              }

            } catch (error) {
              console.log('Ошибка в catch setItem при проверке или создании таблицы', error);
            } 
           

          },
        
       
          (err) => { console.log(`Ошибка транзакции в SqliteStore.setItem: ${err.message}.`); reject('Ошибка одной из транзакций sqlite localStorage') },    
          () => { console.log(`Успешная транзакция в SqliteStore.setItem.`); }  
              
        );
    
        
      });
    }
  }


  static getItem = (key: string) => {
    return new Promise((resolve, reject) => {

      if(window.cordova && window.sqlitePlugin){
        let db = SqliteStore.openDbSqlite();
        console.dir('Выполняется getItem');
        db.transaction(
          (tx) => {
         
            tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${SqliteStore.tableName.config}'`, [],
              (tx, res) => {  console.dir('Поиск таблицы в getItem');
                
                if(res.rows.item(0) && res.rows.item(0).name === SqliteStore.tableName.config){    
         
                  tx.executeSql(`SELECT * FROM ${SqliteStore.tableName.config} WHERE key='${key}'`, [], 
                    (tx, res) => { 
                      
                      
                      console.log('Всё что нашлось, то и вернём в resolve/ getItem', res.rows.item(0));
                      resolve({
                        ...res.rows.item(0),
                        value: (res.rows.item(0).type === 'object' || res.rows.item(0).type === 'boolean')
                                ? JSON.parse(res.rows.item(0).value)
                                : res.rows.item(0).value,
                        status: true
                      });                                            
                    },
                    (tx, err) => {console.error(err); }  
                  );
               
                  return;
                }
               
                resolve({status: false, msg: 'Таблицы ещё не существует. Нужно, для начала что-то положить.'});                                        
              },
              (tx, err) => console.error(err)
            ); 
          },
          (error) => { console.log('Ошибка транзакции в SqliteStore.getItem: '); reject({status: false, error}); }, 
          () => { console.log('Успех транзакции SqliteStore.getItem');  }
        );
  
        return;
      }
      reject(new Error('Не установлен плагин cordova || cordova-sqlite-storage'));

    })
  }

}

==> cordova-sqlite-react-1.0.2.tgz: package/SqliteStore/index.ts <==
import { SQLitePlugin } from './../@types/SQLitePlugin.d';
import { CreateTableType, openDbSqlite } from '@utils/SQLite';
// import { createAndWriteInTable } from './createAndWriteInTable';
import { generateSQLCreateTable, generateSQLInsertInto } from '../stringSQL';

//TODO: Довести до ума
export class SqliteStore {
  
  static dbName = (process.env.REACT_APP_SQLITE_DB_NAME as string)
  static tableName = {
    config: 'localStorage',
  }


  static openDbSqlite = (nameDbSqlite = SqliteStore.dbName) => {

    if(!window.db || (nameDbSqlite && !window.db.openDBs[nameDbSqlite]) ){//!Object.keys(window.db.openDBs).length 
   
      return window.db = window.sqlitePlugin.openDatabase({
        name: nameDbSqlite,
        location: 'default',
        androidDatabaseProvider: 'system'
      });
      
    }
    
    return window.db as SQLitePlugin;
  }

  // private static createAndWriteInTable = createAndWriteInTable //TODO: Подумать как организовать такой подход
  private static createAndWriteInTable:CreateTableType = (payload, tableName, isCreateDate) => new Promise<{status: boolean}>((resolve, reject) => {
    let db = SqliteStore.openDbSqlite();
  
    let { newSQLCreate } = generateSQLCreateTable(payload, tableName, isCreateDate)
    let { newSQLInsert, arrValuesPayload } = generateSQLInsertInto(payload, tableName);
    console.group('SqliteStore.openDbSqlite')
      console.log('newSQLCreate: ', newSQLCreate)
      console.log('newSQLInsert: ', newSQLInsert)
      console.log('arrValuesPayload: ', arrValuesPayload)
    console.groupEnd();

    db.transaction(
      (tx) => {
        tx.executeSql(`DROP TABLE IF EXISTS ${tableName}`);
        tx.executeSql(newSQLCreate);
        tx.executeSql(newSQLInsert, arrValuesPayload, () => resolve({status: true}));
      },
      (err) => { console.error(`>>> Ошибка в SqliteStore -> createTable <<<: ${err}`); reject(new Error('Не удалось создать и записать в таблицу'))  },
      () => { console.dir('Успешное создание таблицы');  }
    )
  
  })

  static checkTable = (nameTable: string) => { 
    return new Promise<{status: boolean}>((resolve, reject) => {

      let db = SqliteStore.openDbSqlite();
      db.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${nameTable}'`, [],
        (res) => {
          
          if(res.rows.item(0) && res.rows.item(0).name === nameTable){    
            resolve({ status: true })
            return;
          }
          resolve({ status: false });                                        
        },
        (err) => { console.log(`Ошибка транзакции в SqliteStore.checkTable: ${err.message}.`); reject('Ошибка проверки таблицы') },    
      ); 
    })
  }



  static setItem = (key:string, value: any) => {
    if(window.cordova){
      return new Promise( (resolve, reject) => {
      
        let db = SqliteStore.openDbSqlite();
       //не проверяю таблицу в отдельной транзакции
        db.transaction(
          async (tx) => {
            try {
          
              let { status } =  await SqliteStore.checkTable(SqliteStore.tableName.config);

              if(status){
                tx.executeSql(`SELECT * FROM ${SqliteStore.tableName.config} WHERE key='${key}'`, [], 
                //Если есть данные и они не совпадают то обновим, если нет их совсем - добавим
                  (tx, res) => {
                    if(!res.rows.item(0)){

                      tx.executeSql(`INSERT INTO ${SqliteStore.tableName.config}(key, value, type) VALUES (?,?,?)`, 
                        [
                          key,
                          ((typeof value === 'object') || (typeof value === 'boolean')) ? JSON.stringify(value) : value,
                          typeof value
                        ],
                        () => {resolve({status: true, msg: 'Успешно положили данные в sqlite LocalStorage'})}
                      );

                    }else if(res.rows.item(0).value !== value){
                      console.dir('Обновляем данные SqliteStore');
                      tx.executeSql(`UPDATE ${SqliteStore.tableName.config} SET value = ?, type = ? WHERE key='${key}'`,
                        [
                          (typeof value === 'object' || typeof value === 'boolean') ? JSON.stringify(value) : value,
                          typeof value
                        ],
                        (tx, res) => { resolve({status: true, id: res.insertId})}
                      );

                    }else{

                      resolve({status: true, msg: 'Данные не обновил т.к. значение тоже'});

                    }
                  } 
                )
              }else{
                console.dir(`Попали в транзакцию создания таблицы ${SqliteStore.tableName.config}`);
                let payload = { key, value, type: typeof value };
                console.log('payload DarkMode для SqliteStore.createAndWriteInTable', payload);
                let dataStatus:object = await SqliteStore.createAndWriteInTable(payload, SqliteStore.tableName.config);
                console.log('dataStatus в SqliteStore.setItem', dataStatus);
                resolve(dataStatus)
              }

            } catch (error) {
              console.log('Ошибка в catch setItem при проверке или создании таблицы', error);
            } 
           

          },
        
       
          (err) => { console.log(`Ошибка транзакции в SqliteStore.setItem: ${err.message}.`); reject('Ошибка одной из транзакций sqlite localStorage') },    
          () => { console.log(`Успешная транзакция в SqliteStore.setItem.`); }  
              
        );
    
        
      });
    }
  }


  static getItem = (key: string) => {
    return new Promise<{
      status: boolean;
      value?: any;
      msg?: string;
      
      }>((resolve, reject) => {

      if(window.cordova && window.sqlitePlugin){
        let db = SqliteStore.openDbSqlite();
        console.dir('Выполняется getItem');
        db.transaction(
          (tx) => {
         
            tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${SqliteStore.tableName.config}'`, [],
              (tx, res) => {  console.dir('Поиск таблицы в getItem');
                
                if(res.rows.item(0) && res.rows.item(0).name === SqliteStore.tableName.config){    
         
                  tx.executeSql(`SELECT * FROM ${SqliteStore.tableName.config} WHERE key='${key}'`, [], 
                    (tx, res) => { 
                      
                      
                      console.log('Всё что нашлось, то и вернём в resolve/ getItem', res.rows.item(0));
                      resolve({
                        ...res.rows.item(0),
                        value: (res.rows.item(0).type === 'object' || res.rows.item(0).type === 'boolean')
                                ? JSON.parse(res.rows.item(0).value)
                                : res.rows.item(0).value,
                        status: true
                      });                                            
                    },
                    (tx, err) => {console.error(err); }  
                  );
               
                  return;
                }
               
                resolve({status: false, msg: 'Таблицы ещё не существует. Нужно, для начала что-то положить.'});                                        
              },
              (tx, err) => console.error(err)
            ); 
          },
          (error) => { console.log('Ошибка транзакции в SqliteStore.getItem: '); reject({status: false, error}); }, 
          () => { console.log('Успех транзакции SqliteStore.getItem');  }
        );
  
        return;
      }
      reject(new Error('Не установлен плагин cordova || cordova-sqlite-storage'));

    })
  }

}
